{% load i18n %}
{% load static %}
{% load humanize %}

<div class="modal-content">
    <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">
            &times;
        </span></button>
        <h4 class="modal-title" id="modalTitle">{% translate 'View Request' %}</h4>
    </div>

    <div class="modal-body">

        <div class="form-horizontal">
            <div class="form-group">
                <label class="col-sm-4">{% translate "User" %}</label>
                <div class='col-sm-8'>{{ request.user }}</div>
            </div>
            <div class="form-group">
                <label class="col-sm-4">{% translate "Start" %}</label>
                <div class='col-sm-8'>{{ request.start }}</div>
            </div>
            <div class="form-group">
                <label class="col-sm-4">{% translate "End" %}</label>
                <div class='col-sm-8'>{{ request.end }}</div>
            </div>
            <div class="form-group">
                <label class="col-sm-4">{% translate "Notes" %}</label>
                <div class='col-sm-8'>{{ request.notes }}</div>
            </div>
        </div>
    </div>

    <div class="modal-footer">
        </div>
</div>
